@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -77,7 +77,7 @@
 #include <yaz/wrbuf.h>
 
 YAZ_BEGIN_CDECL
-    
+
 #define CCL_ERR_OK                0
 #define CCL_ERR_TERM_EXPECTED     1
 #define CCL_ERR_RP_EXPECTED       2
@@ -91,14 +91,16 @@ YAZ_BEGIN_CDECL
 #define CCL_ERR_TRUNC_NOT_LEFT   10
 #define CCL_ERR_TRUNC_NOT_BOTH   11
 #define CCL_ERR_TRUNC_NOT_RIGHT  12
-    
+#define CCL_ERR_TRUNC_NOT_EMBED  13
+#define CCL_ERR_TRUNC_NOT_SINGLE 14
+
 /** \brief attribute node (type, value) pair as used in RPN */
 struct ccl_rpn_attr {
     /** \brief next attribute */
     struct ccl_rpn_attr *next;
     /** \brief attribute set */
     char *set;
-    /** \brief attribute type, Bib-1: 1=use, 2=relation, 3=position, .. */
+    /** \brief attribute type, Bib-1: 1=use, 2=relation, 3=position, etc */
     int type;
     /** \brief attribute value type (numeric or string) */
     int kind;
@@ -124,7 +126,7 @@ enum ccl_rpn_kind {
 
 /** \brief RPN tree structure node */
 struct ccl_rpn_node {
-    /** \brief node type, one of CCL_RPN_AND, CCL_RPN_OR,.. */
+    /** \brief node type, one of CCL_RPN_AND, CCL_RPN_OR, etc */
     enum ccl_rpn_kind kind;
     union {
         /** \brief Boolean including proximity 0=left, 1=right, 2=prox parms */
@@ -145,10 +147,10 @@ typedef struct ccl_qualifiers *CCL_bibset;
 
 /** \brief CCL parser */
 typedef struct ccl_parser *CCL_parser;
-    
+
 /**
    \brief parse CCL find string using CCL profile return RPN tree
-   
+
    Parses a CCL Find command in a simple C string. Returns CCL parse
    tree node describing RPN if parsing is successful. If parsing is
    unsuccesful, NULL is returned and error and pos is set accordingly.
@@ -160,7 +162,7 @@ struct ccl_rpn_node *ccl_find_str(CCL_bibset bibset,
 
 /**
    \brief parse CCL find string with parser and return RPN tree
-   
+
    Parses a CCL Find command in a simple C string. Returns CCL parse
    tree node describing RPN if parsing is successful. If parsing is
    unsuccesful, NULL is returned and error and pos is set accordingly.
@@ -221,11 +223,18 @@ void ccl_qual_line(CCL_bibset bibset, char *line);
 YAZ_EXPORT
 void ccl_qual_fitem(CCL_bibset bibset, const char *value,
                     const char *qual_name);
+YAZ_EXPORT
+int ccl_qual_fitem2(CCL_bibset bibset, const char *value,
+                    const char *qual_name, const char **addinfo);
 
 /** Make CCL qualifier set */
 YAZ_EXPORT
 CCL_bibset ccl_qual_mk(void);
 
+/** Make CCL qualifier set from an existing one (duplicate it) */
+YAZ_EXPORT
+CCL_bibset ccl_qual_dup(CCL_bibset b);
+
 /** Delete CCL qualifier set */
 YAZ_EXPORT
 void ccl_qual_rm(CCL_bibset *b);
@@ -296,6 +305,11 @@ YAZ_EXPORT
 int ccl_stop_words_info(ccl_stop_words_t csw, int idx,
                         const char **qualname, const char **term);
 
+YAZ_EXPORT
+struct ccl_rpn_attr *ccl_parser_qual_search(CCL_parser cclp, const char *name,
+                                            size_t name_len);
+
+
 #ifndef ccl_assert
 #define ccl_assert(x) ;
 #endif
@@ -323,11 +337,11 @@ int ccl_stop_words_info(ccl_stop_words_t csw, int idx,
                              3  key
                              4  year
                              5  date (normalized)
-                             6  word list 
+                             6  word list
                            100  date (un-normalized)
                            101  name (normalized)
                            102  name (un-normalized)
-   truncation (5)                            
+   truncation (5)
    completeness (6)
 */
 
@@ -341,14 +355,18 @@ int ccl_stop_words_info(ccl_stop_words_t csw, int idx,
 #define CCL_BIB1_STR_WP (-1)
 #define CCL_BIB1_STR_AND_LIST (-2)
 #define CCL_BIB1_STR_OR_LIST (-3)
+#define CCL_BIB1_STR_AUTO_GROUP (-4)
+#define CCL_BIB1_STR_SPLIT_LIST (-5)
 #define CCL_BIB1_REL_ORDER (-1)
 #define CCL_BIB1_REL_PORDER (-2)
+#define CCL_BIB1_REL_OMIT_EQUALS (-3)
 
 #define CCL_BIB1_TRU_CAN_LEFT (-1)
 #define CCL_BIB1_TRU_CAN_RIGHT (-2)
 #define CCL_BIB1_TRU_CAN_BOTH  (-3)
 #define CCL_BIB1_TRU_CAN_NONE  (-4)
-
+#define CCL_BIB1_TRU_CAN_REGEX (-5)
+#define CCL_BIB1_TRU_CAN_Z3958 (-6)
 
 
 YAZ_END_CDECL
