@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -45,9 +45,6 @@ typedef enum oid_proto
 {
     PROTO_NOP=0,
     PROTO_Z3950,
-    PROTO_SR,
-    PROTO_GENERAL,
-    PROTO_WAIS,
     PROTO_HTTP
 } oid_proto;
 
