@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -43,6 +43,10 @@ YAZ_EXPORT void yaz_query_charset_convert_apt(Z_AttributesPlusTerm *apt,
 
 YAZ_EXPORT void yaz_query_charset_convert_rpnquery(Z_RPNQuery *q,
                                                    ODR o, yaz_iconv_t cd);
+
+YAZ_EXPORT int yaz_query_charset_convert_rpnquery_check(Z_RPNQuery *q,
+                                                        ODR o, yaz_iconv_t cd);
+
 YAZ_END_CDECL
 
 #endif
