@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -41,7 +41,17 @@ YAZ_EXPORT COMSTACK tcpip_type(int s, int flags, int protocol, void *vp);
 YAZ_EXPORT COMSTACK ssl_type(int s, int flags, int protocol, void *vp);
 YAZ_EXPORT COMSTACK yaz_tcpip_create(int s, int flags, int protocol,
                                      const char *connect_host);
-
+YAZ_EXPORT COMSTACK yaz_tcpip_create2(int s, int flags, int protocol,
+                                      const char *connect_host,
+                                      const char *bind_host);
+YAZ_EXPORT COMSTACK yaz_tcpip_create3(int s, int flags, int protocol,
+                                      const char *connect_host,
+                                      const char *connect_auth,
+                                      const char *bind_host);
+YAZ_EXPORT COMSTACK yaz_ssl_create(int s, int flags, int protocol,
+                                   const char *connect_host,
+                                   const char *connect_auth,
+                                   const char *bind_host);
 YAZ_END_CDECL
 
 #endif
